---
type: user/information
description: Feature flags overview
usage: ":flags"
aliases:
  - flags
category: project-and-feature-flags
---
{{h1}}Feature Flags

{{h2}}Commands
- `{{@}}guide :flags/list` - List all flags (project and feature)
- `{{@}}guide :flags/project/list` - List project flags only
- `{{@}}guide :flags/feature/list` - List feature flags only

{{h2}}Project Flags
Flags specific to the current project.

Commands:
- `{{@}}guide :flags/project/get <flag-name>` - Get flag value
- `{{@}}guide :flags/project/set <flag-name>` - Set flag value
- `{{@}}guide :flags/project/remove <flag-name>` - Remove flag override

{{h2}}Feature Flags
Flags that apply across all projects.

Commands:
- `{{@}}guide :flags/feature/get <flag-name>` - Get flag value
- `{{@}}guide :flags/feature/set <flag-name>` - Set flag value
- `{{@}}guide :flags/feature/remove <flag-name>` - Remove flag

{{h2}}Available Flags

{{h3}}workflow
Enable workflow phase tracking
- Scope: Project and Feature

{{h3}}openspec
Enable OpenSpec integration
- Scope: Project and Feature

{{h3}}content-style
Output format (None, plain, mime)
- Scope: Project and Feature

{{h3}}autoupdate
Automatic content updates
- Scope: Feature only

