---
type: user/information
description: Shows current project information and configuration
category: project
usage: ":project [--verbose|-v] [--table|-t]"
aliases: ["project"]
includes:
  - ../_partials/project
---
{{h1}}Project Information

{{>project}}

