---
type: agent/instruction
description: Remove feature flag
usage: ":flags/feature/remove <flag-name>"
aliases:
  - flags/feature/remove
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
category: project-and-feature-flags
---
{{#args.0.value}}
Use the set_feature_flag tool with:
feature_name: '{{args.0.value}}'
value: null
{{/args.0.value}}
{{^args.0.value}}
{{#_error}}Missing required argument: flag-name{{/_error}}

{{b}}Usage:{{b}} {{@}}guide :flags/feature/remove <flag-name>

{{b}}Example:{{b}} {{@}}guide :flags/feature/remove workflow
{{/args.0.value}}
