---
type: agent/instruction
description: Get feature flag value or filter by pattern
usage: ":flags/feature/get <flag-name-or-pattern>"
aliases:
  - flags/feature/get
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
category: project-and-feature-flags
---
{{#args.0.value}}
Use the list_feature_flags tool with:
feature_name: '{{args.0.value}}'

If the value contains wildcards (* ? [), returns dict of matching flags.
Otherwise returns single flag value.
{{/args.0.value}}
{{^args.0.value}}
{{#_error}}Missing required argument: flag-name-or-pattern{{/_error}}

{{b}}Usage:{{b}} {{@}}guide :flags/feature/get <flag-name-or-pattern>

{{b}}Examples:{{b}}
  {{@}}guide :flags/feature/get allow-client-info  # Get single flag
  {{@}}guide :flags/feature/get allow-*            # Get all allow-* flags
{{/args.0.value}}
