---
type: user/information
description: Show document commands
usage: ":document"
instruction: ^ Display this information to the user
---
{{h1}}Document Commands

{{b}}Available commands:{{b}}
- `{{@}}guide :document/add <category> <path>` - Add a local file to the document store
- `{{@}}guide :document/remove <category> <name>` - Remove a stored document
- `{{@}}guide :document/list <category>` - List stored documents in a category
