---
type: agent/instruction
description: Add a new collection to the current project
usage: ":project/collection/add <name> [--categories=<categories>] [--description=<text>]"
aliases:
  - collection/add
argrequired:
  - categories
  - description
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
category: project-collections
---
{{#args.0.value}}
Use the category_collection_add tool with:
type: 'collection'
name: '{{args.0.value}}'
{{#kwargs.categories}}
categories: {{kwargs.categories}}
{{/kwargs.categories}}
{{#kwargs.description}}
description: '{{kwargs.description}}'
{{/kwargs.description}}
{{/args.0.value}}
{{^args.0.value}}
{{#_error}}Missing required argument: name{{/_error}}

{{b}}Usage:{{b}} {{@}}guide :project/collection/add <name> [--categories=<categories>] [--description=<text>]

{{b}}Example:{{b}} {{@}}guide :project/collection/add my-collection --categories="docs,guide" --description="Documentation and guidelines"
{{/args.0.value}}
