---
type: agent/instruction
description: Remove a stored document
usage: ":document/remove <category> <name>"
category: project
minargs: 2
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
---
Remove Stored Document

Call the `{{tool_prefix}}document_remove` tool:

```
{{tool_prefix}}document_remove(
    category="{{args.0.value}}",
    name="{{args.1.value}}"
)
```
