---
type: user/information
description: OpenSpec commands overview
usage: ":openspec"
aliases:
  - openspec
category: openspec
---
{{h1}}OpenSpec Commands

{{h2}}Change Management
- `{{@}}guide :openspec/list` - List all active changes
- `{{@}}guide :openspec/show [<change-id>]` - Show details for a change
- `{{@}}guide :openspec/status [<change-id>]` - Get completion status for a change
- `{{@}}guide :openspec/propose [<change-id>]` - Create a new change proposal
- `{{@}}guide :openspec/validate [<change-id>]` - Validate a change
- `{{@}}guide :openspec/archive [<change-id>]` - Archive a completed change

{{h2}}Project Setup
- `{{@}}guide :openspec/init` - Initialise OpenSpec in the current project
- `{{@}}guide :openspec/schemas` - Discover available schemas in the project
