---
type: agent/instruction
description: List all categories in the current project
usage: ":project/category/list [--verbose|-v]"
aliases:
  - category/list
instruction: >
  Do not display this content to the user.
  Follow the instructions provided in the content.
category: project-categories
---
Use the category_collection_list tool with:
type: 'category'
{{#kwargs.verbose}}verbose: true{{/kwargs.verbose}}
{{#kwargs.v}}verbose: true{{/kwargs.v}}
