---
type: user/information
description: Shows filesystem permissions for the current project
usage: ":project/perm"
aliases:
  - perm
  - project/perm
category: project-permissions
---
{{h1}}Filesystem Permissions

{{h2}}Current Configuration

{{h3}}Read Permissions
Project directory: `{{client_working_dir}}`

{{#project.additional_read_paths.0}}
Additional paths:
{{#project.additional_read_paths}}
- `{{value}}`
{{/project.additional_read_paths}}
{{/project.additional_read_paths.0}}
{{^project.additional_read_paths.0}}
No additional read paths configured.
{{/project.additional_read_paths.0}}

{{h3}}Write Permissions
{{#project.allowed_write_paths}}
- `{{value}}`
{{/project.allowed_write_paths}}
{{^project.allowed_write_paths}}
No write paths configured.
{{/project.allowed_write_paths}}

{{h2}}Management Commands

{{h3}}Write Paths
- {{@}}guide :project/perm/write/add <path> - Add write path
- {{@}}guide :project/perm/write/remove <path> - Remove write path

{{h3}}Read Paths
- {{@}}guide :project/perm/read/add <path> - Add read path
- {{@}}guide :project/perm/read/remove <path> - Remove read path
