---
type: agent/instruction
Description: Review project changes
usage: ":workflow/review"
aliases:
  - review
category: "project-workflow"
instruction: Perform a review of project changes. {{INSTRUCTION_AGENT_INSTRUCTIONS}}
includes:
  - ../_partials/client-info
---
{{#workflow}}You MUST transition to REVIEW phase.
{{/workflow}}
{{h1}}Perform a Code Review

{{#agent.class}}
{{#equals}}kiro{{agent.class}}
  — Use `use_subagent` to delegate review to `guide-review` agent with the instructions below.
{{/equals}}
{{#equals}}q-dev{{agent.class}}
  — Use `use_subagent` to delegate review to `guide-review` agent with the instructions below.
{{/equals}}

{{b}}Review Instructions:{{b}}
  — You MUST NOT consider previous conversational history when conducting this review.
    {{b}}This review must be done with a fresh look without consideration of previous work, including any fixes and tests.{{b}}
  — Use {{#resource}}code-review{{/resource}} to access code review guidelines.
  — Read {{workflow.file}} to understand the current issue context {{#workflow.issue}}(issue: {{workflow.issue}}).{{/workflow.issue}}
  — Analyse changes against HEAD and create or update review artifact in `{{#workflow.issue}}{{path.documents}}{{workflow.issue}}-review.md{{/workflow.issue}}{{^workflow.issue}}{{path.documents}}{{/workflow.issue}}`

{{#openspec}}{{b}}NOTE{{b}} Review artifacts are NEVER to be created in the openspec changes directory{{/openspec}}
{{/agent.class}}
{{^agent.class}}
{{>client-info}}
{{/agent.class}}
