---
type: agent/instruction
instruction: ^Run the {{tool_prefix}}client_info tool to retrieve client information. {{INSTRUCTION_AGENT_INSTRUCTIONS}}
---
{{b}}Agent Detection Required{{b}}
  — Run {{tool_prefix}}client_info() to detect the agent information
  — Report the result to the user
  — Ask the user to run this command again after agent detection completes
